from time import mktime
from django.db import models


class Minimizer(models.Model):
    created_at = models.DateTimeField(auto_now_add=True)

    def __unicode__(self):
        return str(self.timestamp)

    @property
    def timestamp(self):
        return int(mktime(self.created_at.timetuple()))

    class Meta:
        ordering = ('-created_at',)
        get_latest_by = ('created_at',)



import os
from django.conf import settings

MINIMIZER_DEBUG = getattr(settings, 'MINIMIZER_DEBUG', settings.DEBUG)
CLOSURE_PATH = getattr(settings, 'MINIMIZER_CLOSURE_PATH', '')
SCRIPTS = getattr(settings, 'MINIMIZER_SCRIPTS', [])
STYLES = getattr(settings, 'MINIMIZER_STYLES', [])
JQUERY_VERSION = getattr(settings, 'MINIMIZER_JQUERY_VERSION', '1.7')
DESCRIPTION = getattr(settings, 'MINIMIZER_DESCRIPTION', '')
AUTHOR = getattr(settings, 'MINIMIZER_AUTHOR', '')
GOOGLE_ANALYTICS_CODE = getattr(
    settings, 'MINIMIZER_GOOGLE_ANALYTICS_CODE', '')

# Tool settings
JS_PATH = os.path.join(settings.STATIC_ROOT, 'js')
CSS_PATH = os.path.join(settings.STATIC_ROOT, 'css')
TOOLS_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), 'tools'))
YUI_COMPRESSOR = 'yuicompressor-2.4.7.jar'



import os
from subprocess import call
from django.contrib.staticfiles.management.commands.collectstatic \
    import Command as CollectStaticCommand
from djangominimizer import settings
from djangominimizer.models import Minimizer


# FIXME: Is it true way to override command?
class Command(CollectStaticCommand):
    def handle_noargs(self, **options):
        super(Command, self).handle_noargs(**options)

        print("\n\nNow, this will compress javascript and css files.")
        self.missing_files = 0
        self.minimizer = Minimizer.objects.create()
        self.cmd_template = 'java -jar %(yui)s -o %(file_min)s %(file)s'

        # compress script files.
        self.run_yui(settings.SCRIPTS, settings.JS_PATH)

        # then, comress style files.
        self.run_yui(settings.STYLES, settings.CSS_PATH)

        if self.missing_files:
            print("%s file(s) not compiled. Please check these files." % \
                  self.missing_files)

    def run_yui(self, file_list, static_path):
        for static_file in file_list:
            file_path = os.path.join(static_path, static_file)

            if not os.path.exists(file_path):
                self.missing_files += 1
                print("Missing file, %s" % static_file)

                continue

            print("Compressing %s..." % static_file)
            file_min_path = '%s-%s.js' % (
                os.path.splitext(file_path)[0], self.minimizer.timestamp)

            cmd = self.cmd_template % {
                'yui': os.path.join(
                    settings.TOOLS_PATH, settings.YUI_COMPRESSOR),
                'file': file_path,
                'file_min': file_min_path
            }

            call(cmd.split())



import os
from django.template import Library
from djangominimizer import settings
from djangominimizer.models import Minimizer
from djangominimizer.utils import get_minimizer_list

register  = Library()


@register.inclusion_tag('minimizer/tags/styles.html', takes_context=True)
def minimizer_styles(context):
    arguments = {
        'STATIC_URL': context['STATIC_URL'],
        'styles': get_minimizer_list(settings.STYLES)
    }

    return arguments


@register.inclusion_tag('minimizer/tags/scripts.html', takes_context=True)
def minimizer_scripts(context):
    arguments = {
        'STATIC_URL': context['STATIC_URL'],
        'scripts': get_minimizer_list(settings.SCRIPTS)
    }

    return arguments



from djangominimizer import settings


def minimizer_settings(request):
    """
    Adds minimizer_settings variables to the context.
    """
    context_data = {
        'MINIMIZER_JQUERY_VERSION': settings.JQUERY_VERSION,
        'MINIMIZER_DESCRIPTION': settings.DESCRIPTION,
        'MINIMIZER_AUTHOR': settings.AUTHOR,
        'MINIMIZER_GOOGLE_ANALYTICS_CODE': settings.GOOGLE_ANALYTICS_CODE
    }

    return context_data



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Deleting field 'Minimizer.script_name'
        db.delete_column('djangominimizer_minimizer', 'script_name')


    def backwards(self, orm):
        
        # Adding field 'Minimizer.script_name'
        db.add_column('djangominimizer_minimizer', 'script_name', self.gf('django.db.models.fields.CharField')(default='', max_length=128, blank=True), keep_default=False)


    models = {
        'djangominimizer.minimizer': {
            'Meta': {'ordering': "('-created_at',)", 'object_name': 'Minimizer'},
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        }
    }

    complete_apps = ['djangominimizer']



# -*- coding: utf-8 -*-
from setuptools import setup
from setuptools import find_packages

VERSION = '0.1.1'
DESCRIPTION = """\
Django application for minimizing static files and using simple html5 template
 with jQuery and modernizr."""

setup(
    name='django-minimizer',
    version=VERSION,
    description=DESCRIPTION,
    url='http://django-minimizer.alageek.com',
    author='Gökmen Görgen',
    author_email='gokmen@alageek.com',
    packages=find_packages(exclude=('website', 'website.*')),
    include_package_data=True,
    license='GPLv3',
    keywords='django application html5 yui compressor jquery modernizr',
    install_requires=[
        'Django>=1.3',
    ]
)



from djangominimizer import settings
from djangominimizer.models import Minimizer


def get_minimizer_list(file_list):
    if not settings.MINIMIZER_DEBUG:
        try:
            minimizer = Minimizer.objects.latest()
            file_min_list = []

            for file_orig in file_list:
                file_min = ('-%s' % minimizer.timestamp).join(
                    os.path.splitext(script))
                file_min_list.append(file_min)

            return file_min_list

        except Minimizer.DoesNotExist:
            pass

    return file_list
